===============================
jarvispatrick
===============================

.. image:: https://img.shields.io/pypi/v/jarvispatrick.svg
        :target: https://pypi.python.org/pypi/jarvispatrick

.. image:: https://img.shields.io/travis/llazzaro/jarvispatrick.svg
        :target: https://travis-ci.org/llazzaro/jarvispatrick

.. image:: https://readthedocs.org/projects/jarvispatrick/badge/?version=latest
        :target: https://readthedocs.org/projects/jarvispatrick/?badge=latest
        :alt: Documentation Status


Jarvis-Patrick Clustering that uses a nearest neighbor approach to clustering objects

* Free software: ISC license
* Documentation: https://jarvispatrick.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
